// created by proto.sh from proto.lst
#define P_Str 1
#define P_Newline 2
#define P_Skip 3
#define P_Hline 4
#define P_Dispolast 5
#define P_Label 6
#define P_String 7
#define P_Checkbox 8
#define P_Radio 9
#define P_Button 10
#define P_Button_xpm 11
#define P_Button_xpmf 12
#define P_Choice 13
#define P_Choice_item 14
#define P_List 15
#define P_List_item 16
#define P_Combo 17
#define P_Combo_item 18
#define P_Group 19
#define P_Form 20
#define P_Page 21
#define P_Book 22
#define P_MainForm 23
#define P_End 24
#define P_Delete 25
#define P_Dump 26
#define P_Icon_xpm 27
#define P_Xfer_xpm 28
#define P_Sidetitle 29
#define P_Fill 30
#define P_Formbutton 31
#define P_Groupfit 32
#define P_Setweightlast 33
#define P_Richtext 34
#define P_Password 35
#define P_Buttonfill 36
#define P_Enteraction 37
#define P_Curfield 38
#define P_Version 39
#define P_Treemenu 40
#define P_Treeelem 41
#define P_Clist 42
#define P_Clist_item 43
#define P_Html 44
#define P_Treesub 45
#define P_Sheet 46
#define P_Sheet_item 47
#define P_Textarea 48
#define P_Slider 49
#define P_Gauge 50
#define P_Setval 51
#define P_Alive 52
#define P_Setcontext 53
#define P_Defdc 54
#define P_Deffont 55
#define P_Defpen 56
#define P_Defbrush 57
#define P_Drawline 58
#define P_Drawrect 59
#define P_Drawarc 60
#define P_Fillrect 61
#define P_Fillarc 62
#define P_Menubar 63
#define P_Popupmenu 64
#define P_Submenu 65
#define P_Menuentry 66
#define P_Clear 67
#define P_Drawclip 68
#define P_Setcursor 69
#define P_Blit 70
#define P_Drawtext 71
#define P_Refresh 72
#define P_Menutitle 73
#define P_Listen 74
#define P_Prefsubmenu 75
#define P_Show 76
#define P_Inputgrid 77
#define P_Fillpolygon 78
#define P_Splash 79
#define P_Hidesplash 80
#define P_Deletechild 81
